# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class AuthResultOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'token_info': 'TokenModel',
        'tenant_id': 'str',
        'user_id': 'str',
        'state': 'int',
        'err_msg': 'str'
    }

    attribute_map = {
        'token_info': 'tokenInfo',
        'tenant_id': 'tenantId',
        'user_id': 'userId',
        'state': 'state',
        'err_msg': 'errMsg'
    }

    def __init__(self, token_info=None, tenant_id=None, user_id=None, state=None, err_msg=None, local_vars_configuration=None):  # noqa: E501
        """AuthResultOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._token_info = None
        self._tenant_id = None
        self._user_id = None
        self._state = None
        self._err_msg = None
        self.discriminator = None

        if token_info is not None:
            self.token_info = token_info
        self.tenant_id = tenant_id
        self.user_id = user_id
        if state is not None:
            self.state = state
        self.err_msg = err_msg

    @property
    def token_info(self):
        """Gets the token_info of this AuthResultOutput.  # noqa: E501


        :return: The token_info of this AuthResultOutput.  # noqa: E501
        :rtype: TokenModel
        """
        return self._token_info

    @token_info.setter
    def token_info(self, token_info):
        """Sets the token_info of this AuthResultOutput.


        :param token_info: The token_info of this AuthResultOutput.  # noqa: E501
        :type: TokenModel
        """

        self._token_info = token_info

    @property
    def tenant_id(self):
        """Gets the tenant_id of this AuthResultOutput.  # noqa: E501


        :return: The tenant_id of this AuthResultOutput.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this AuthResultOutput.


        :param tenant_id: The tenant_id of this AuthResultOutput.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def user_id(self):
        """Gets the user_id of this AuthResultOutput.  # noqa: E501


        :return: The user_id of this AuthResultOutput.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this AuthResultOutput.


        :param user_id: The user_id of this AuthResultOutput.  # noqa: E501
        :type: str
        """

        self._user_id = user_id

    @property
    def state(self):
        """Gets the state of this AuthResultOutput.  # noqa: E501

        0-Ready 1-Authorizing 2-Success 3-Error   # noqa: E501

        :return: The state of this AuthResultOutput.  # noqa: E501
        :rtype: int
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this AuthResultOutput.

        0-Ready 1-Authorizing 2-Success 3-Error   # noqa: E501

        :param state: The state of this AuthResultOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and state not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `state` ({0}), must be one of {1}"  # noqa: E501
                .format(state, allowed_values)
            )

        self._state = state

    @property
    def err_msg(self):
        """Gets the err_msg of this AuthResultOutput.  # noqa: E501


        :return: The err_msg of this AuthResultOutput.  # noqa: E501
        :rtype: str
        """
        return self._err_msg

    @err_msg.setter
    def err_msg(self, err_msg):
        """Sets the err_msg of this AuthResultOutput.


        :param err_msg: The err_msg of this AuthResultOutput.  # noqa: E501
        :type: str
        """

        self._err_msg = err_msg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthResultOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AuthResultOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class OrganizationWithUserStatusInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'name': 'str',
        'level_code': 'str',
        'parent_level_code': 'str',
        'users': 'list[UserInfoWithStatus]',
        'is_has_children': 'bool',
        'children': 'list[OrganizationWithUserStatusInfo]'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'level_code': 'levelCode',
        'parent_level_code': 'parentLevelCode',
        'users': 'users',
        'is_has_children': 'isHasChildren',
        'children': 'children'
    }

    def __init__(self, id=None, name=None, level_code=None, parent_level_code=None, users=None, is_has_children=None, children=None, local_vars_configuration=None):  # noqa: E501
        """OrganizationWithUserStatusInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._name = None
        self._level_code = None
        self._parent_level_code = None
        self._users = None
        self._is_has_children = None
        self._children = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.name = name
        self.level_code = level_code
        self.parent_level_code = parent_level_code
        self.users = users
        if is_has_children is not None:
            self.is_has_children = is_has_children
        self.children = children

    @property
    def id(self):
        """Gets the id of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The id of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrganizationWithUserStatusInfo.


        :param id: The id of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The name of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrganizationWithUserStatusInfo.


        :param name: The name of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def level_code(self):
        """Gets the level_code of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The level_code of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._level_code

    @level_code.setter
    def level_code(self, level_code):
        """Sets the level_code of this OrganizationWithUserStatusInfo.


        :param level_code: The level_code of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: str
        """

        self._level_code = level_code

    @property
    def parent_level_code(self):
        """Gets the parent_level_code of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The parent_level_code of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: str
        """
        return self._parent_level_code

    @parent_level_code.setter
    def parent_level_code(self, parent_level_code):
        """Sets the parent_level_code of this OrganizationWithUserStatusInfo.


        :param parent_level_code: The parent_level_code of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: str
        """

        self._parent_level_code = parent_level_code

    @property
    def users(self):
        """Gets the users of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The users of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: list[UserInfoWithStatus]
        """
        return self._users

    @users.setter
    def users(self, users):
        """Sets the users of this OrganizationWithUserStatusInfo.


        :param users: The users of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: list[UserInfoWithStatus]
        """

        self._users = users

    @property
    def is_has_children(self):
        """Gets the is_has_children of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The is_has_children of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: bool
        """
        return self._is_has_children

    @is_has_children.setter
    def is_has_children(self, is_has_children):
        """Sets the is_has_children of this OrganizationWithUserStatusInfo.


        :param is_has_children: The is_has_children of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: bool
        """

        self._is_has_children = is_has_children

    @property
    def children(self):
        """Gets the children of this OrganizationWithUserStatusInfo.  # noqa: E501


        :return: The children of this OrganizationWithUserStatusInfo.  # noqa: E501
        :rtype: list[OrganizationWithUserStatusInfo]
        """
        return self._children

    @children.setter
    def children(self, children):
        """Sets the children of this OrganizationWithUserStatusInfo.


        :param children: The children of this OrganizationWithUserStatusInfo.  # noqa: E501
        :type: list[OrganizationWithUserStatusInfo]
        """

        self._children = children

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrganizationWithUserStatusInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrganizationWithUserStatusInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_iot_service.api_client import ApiClient
from dhicn_iot_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class TelemetryApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_v1_iot_latest_timeseries_post(self, **kwargs):  # noqa: E501
        """根据指标获取最新实测数据，要求指标编码再系统中是唯一的  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_latest_timeseries_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LatestTimeSeriesInput latest_time_series_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[LatestTimeSeriesOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_latest_timeseries_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_latest_timeseries_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据指标获取最新实测数据，要求指标编码再系统中是唯一的  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_latest_timeseries_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param LatestTimeSeriesInput latest_time_series_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[LatestTimeSeriesOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'latest_time_series_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_latest_timeseries_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'latest_time_series_input' in local_var_params:
            body_params = local_var_params['latest_time_series_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/latest-timeseries', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[LatestTimeSeriesOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_query_online_processed_timeseries_get(self, device_id, keys, start_ts, end_ts, **kwargs):  # noqa: E501
        """查询设备指标的时间序列数据 Query time-series data of device indicators  # noqa: E501

        查询设备多个指标在某个时间段内的时间序列数据 Query time-series data of multiple indicators of a device by time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_query_online_processed_timeseries_get(device_id, keys, start_ts, end_ts, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str device_id: 设备ID device id (required)
        :param list[str] keys: 指标列表 indicators (required)
        :param str start_ts: 查询开始时间 start time (required)
        :param str end_ts: 查询结束时间 end time (required)
        :param str order_by: 排序方式，ASC (升序)，DESC (降序) sort order, ASC (ASCENDING) or DESC (DESCENDING);默认是降序DESC
        :param int interval:
        :param str agg:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: dict(str, list[object])
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_query_online_processed_timeseries_get_with_http_info(device_id, keys, start_ts, end_ts, **kwargs)  # noqa: E501

    def api_v1_iot_query_online_processed_timeseries_get_with_http_info(self, device_id, keys, start_ts, end_ts, **kwargs):  # noqa: E501
        """查询设备指标的时间序列数据 Query time-series data of device indicators  # noqa: E501

        查询设备多个指标在某个时间段内的时间序列数据 Query time-series data of multiple indicators of a device by time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_query_online_processed_timeseries_get_with_http_info(device_id, keys, start_ts, end_ts, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str device_id: 设备ID device id (required)
        :param list[str] keys: 指标列表 indicators (required)
        :param str start_ts: 查询开始时间 start time (required)
        :param str end_ts: 查询结束时间 end time (required)
        :param str order_by: 排序方式，ASC (升序)，DESC (降序) sort order, ASC (ASCENDING) or DESC (DESCENDING);默认是降序DESC
        :param int interval:
        :param str agg:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(dict(str, list[object]), status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'device_id',
            'keys',
            'start_ts',
            'end_ts',
            'order_by',
            'interval',
            'agg'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_query_online_processed_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and ('device_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['device_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `device_id` when calling `api_v1_iot_query_online_processed_timeseries_get`")  # noqa: E501
        # verify the required parameter 'keys' is set
        if self.api_client.client_side_validation and ('keys' not in local_var_params or  # noqa: E501
                                                        local_var_params['keys'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `keys` when calling `api_v1_iot_query_online_processed_timeseries_get`")  # noqa: E501
        # verify the required parameter 'start_ts' is set
        if self.api_client.client_side_validation and ('start_ts' not in local_var_params or  # noqa: E501
                                                        local_var_params['start_ts'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `start_ts` when calling `api_v1_iot_query_online_processed_timeseries_get`")  # noqa: E501
        # verify the required parameter 'end_ts' is set
        if self.api_client.client_side_validation and ('end_ts' not in local_var_params or  # noqa: E501
                                                        local_var_params['end_ts'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `end_ts` when calling `api_v1_iot_query_online_processed_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'device_id' in local_var_params and local_var_params['device_id'] is not None:  # noqa: E501
            query_params.append(('DeviceId', local_var_params['device_id']))  # noqa: E501
        if 'keys' in local_var_params and local_var_params['keys'] is not None:  # noqa: E501
            query_params.append(('Keys', local_var_params['keys']))  # noqa: E501
            collection_formats['Keys'] = 'multi'  # noqa: E501
        if 'start_ts' in local_var_params and local_var_params['start_ts'] is not None:  # noqa: E501
            query_params.append(('StartTs', local_var_params['start_ts']))  # noqa: E501
        if 'end_ts' in local_var_params and local_var_params['end_ts'] is not None:  # noqa: E501
            query_params.append(('EndTs', local_var_params['end_ts']))  # noqa: E501
        if 'order_by' in local_var_params and local_var_params['order_by'] is not None:  # noqa: E501
            query_params.append(('OrderBy', local_var_params['order_by']))  # noqa: E501
        if 'interval' in local_var_params and local_var_params['interval'] is not None:  # noqa: E501
            query_params.append(('Interval', local_var_params['interval']))  # noqa: E501
        if 'agg' in local_var_params and local_var_params['agg'] is not None:  # noqa: E501
            query_params.append(('Agg', local_var_params['agg']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/query-online-processed-timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, list[object])',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_save_telemetry_data_batch_post(self, **kwargs):  # noqa: E501
        """批量保存或更新时间序列数据 Batch save or update time-series data  # noqa: E501

        批量保存或更新设备指标的时间序列数据，时间序列数据以json格式传递 Batch save or update device indicator time-series data, data is transferred in the format of json.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_save_telemetry_data_batch_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SaveTelemetryDataInput] save_telemetry_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_save_telemetry_data_batch_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_save_telemetry_data_batch_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量保存或更新时间序列数据 Batch save or update time-series data  # noqa: E501

        批量保存或更新设备指标的时间序列数据，时间序列数据以json格式传递 Batch save or update device indicator time-series data, data is transferred in the format of json.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_save_telemetry_data_batch_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SaveTelemetryDataInput] save_telemetry_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'save_telemetry_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_save_telemetry_data_batch_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_telemetry_data_input' in local_var_params:
            body_params = local_var_params['save_telemetry_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/save-telemetry-data-batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_save_telemetry_data_post(self, **kwargs):  # noqa: E501
        """保存或更新时间序列数据 Save or update time-series data  # noqa: E501

        保存或更新设备指标的时间序列数据，时间序列数据以json格式传递 Save or update device indicator time-series data, data is transferred in the format of json.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_save_telemetry_data_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveTelemetryDataInput save_telemetry_data_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_save_telemetry_data_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_save_telemetry_data_post_with_http_info(self, **kwargs):  # noqa: E501
        """保存或更新时间序列数据 Save or update time-series data  # noqa: E501

        保存或更新设备指标的时间序列数据，时间序列数据以json格式传递 Save or update device indicator time-series data, data is transferred in the format of json.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_save_telemetry_data_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SaveTelemetryDataInput save_telemetry_data_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'save_telemetry_data_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_save_telemetry_data_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_telemetry_data_input' in local_var_params:
            body_params = local_var_params['save_telemetry_data_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/save-telemetry-data', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_timeseries_batch_post(self, **kwargs):  # noqa: E501
        """批量查询设备指标的时间序列数据，按时间排序 Batch query time-series data of device indicators order by time  # noqa: E501

        批量查询设备多个指标在某个时间段内的时间序列数据，可按时间排序 Batch query time-series data of multiple indicators of a device by time and order by time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_timeseries_batch_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TimeseriesInput] timeseries_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[dict(str, list[object])]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_timeseries_batch_post_with_http_info(**kwargs)  # noqa: E501

    def api_v1_iot_timeseries_batch_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量查询设备指标的时间序列数据，按时间排序 Batch query time-series data of device indicators order by time  # noqa: E501

        批量查询设备多个指标在某个时间段内的时间序列数据，可按时间排序 Batch query time-series data of multiple indicators of a device by time and order by time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_timeseries_batch_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TimeseriesInput] timeseries_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[dict(str, list[object])], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'timeseries_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_timeseries_batch_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'timeseries_input' in local_var_params:
            body_params = local_var_params['timeseries_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/timeseries-batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[dict(str, list[object])]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v1_iot_timeseries_get(self, device_id, keys, start_ts, end_ts, **kwargs):  # noqa: E501
        """查询设备指标的时间序列数据，按时间排序 Query time-series data of device indicators order by time  # noqa: E501

        查询设备多个指标在某个时间段内的时间序列数据，可按时间排序 Query time-series data of multiple indicators of a device by time and order by time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_timeseries_get(device_id, keys, start_ts, end_ts, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str device_id: 设备ID device id (required)
        :param list[str] keys: 指标列表 indicators (required)
        :param str start_ts: 查询开始时间 start time (required)
        :param str end_ts: 查询结束时间 end time (required)
        :param str order_by: 排序方式，ASC (升序)，DESC (降序) sort order, ASC (ASCENDING) or DESC (DESCENDING);默认是降序DESC
        :param int interval:
        :param str agg:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: dict(str, list[object])
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v1_iot_timeseries_get_with_http_info(device_id, keys, start_ts, end_ts, **kwargs)  # noqa: E501

    def api_v1_iot_timeseries_get_with_http_info(self, device_id, keys, start_ts, end_ts, **kwargs):  # noqa: E501
        """查询设备指标的时间序列数据，按时间排序 Query time-series data of device indicators order by time  # noqa: E501

        查询设备多个指标在某个时间段内的时间序列数据，可按时间排序 Query time-series data of multiple indicators of a device by time and order by time.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v1_iot_timeseries_get_with_http_info(device_id, keys, start_ts, end_ts, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str device_id: 设备ID device id (required)
        :param list[str] keys: 指标列表 indicators (required)
        :param str start_ts: 查询开始时间 start time (required)
        :param str end_ts: 查询结束时间 end time (required)
        :param str order_by: 排序方式，ASC (升序)，DESC (降序) sort order, ASC (ASCENDING) or DESC (DESCENDING);默认是降序DESC
        :param int interval:
        :param str agg:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(dict(str, list[object]), status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'device_id',
            'keys',
            'start_ts',
            'end_ts',
            'order_by',
            'interval',
            'agg'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v1_iot_timeseries_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'device_id' is set
        if self.api_client.client_side_validation and ('device_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['device_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `device_id` when calling `api_v1_iot_timeseries_get`")  # noqa: E501
        # verify the required parameter 'keys' is set
        if self.api_client.client_side_validation and ('keys' not in local_var_params or  # noqa: E501
                                                        local_var_params['keys'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `keys` when calling `api_v1_iot_timeseries_get`")  # noqa: E501
        # verify the required parameter 'start_ts' is set
        if self.api_client.client_side_validation and ('start_ts' not in local_var_params or  # noqa: E501
                                                        local_var_params['start_ts'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `start_ts` when calling `api_v1_iot_timeseries_get`")  # noqa: E501
        # verify the required parameter 'end_ts' is set
        if self.api_client.client_side_validation and ('end_ts' not in local_var_params or  # noqa: E501
                                                        local_var_params['end_ts'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `end_ts` when calling `api_v1_iot_timeseries_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'device_id' in local_var_params and local_var_params['device_id'] is not None:  # noqa: E501
            query_params.append(('DeviceId', local_var_params['device_id']))  # noqa: E501
        if 'keys' in local_var_params and local_var_params['keys'] is not None:  # noqa: E501
            query_params.append(('Keys', local_var_params['keys']))  # noqa: E501
            collection_formats['Keys'] = 'multi'  # noqa: E501
        if 'start_ts' in local_var_params and local_var_params['start_ts'] is not None:  # noqa: E501
            query_params.append(('StartTs', local_var_params['start_ts']))  # noqa: E501
        if 'end_ts' in local_var_params and local_var_params['end_ts'] is not None:  # noqa: E501
            query_params.append(('EndTs', local_var_params['end_ts']))  # noqa: E501
        if 'order_by' in local_var_params and local_var_params['order_by'] is not None:  # noqa: E501
            query_params.append(('OrderBy', local_var_params['order_by']))  # noqa: E501
        if 'interval' in local_var_params and local_var_params['interval'] is not None:  # noqa: E501
            query_params.append(('Interval', local_var_params['interval']))  # noqa: E501
        if 'agg' in local_var_params and local_var_params['agg'] is not None:  # noqa: E501
            query_params.append(('Agg', local_var_params['agg']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v1/iot/timeseries', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, list[object])',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v2_iot_timeseries_batch_post(self, **kwargs):  # noqa: E501
        """批量查询多个设备指标的时间序列数据，按时间排序 Batch query time-series data of device indicators order by time  # noqa: E501

        批量查询多个设备指标在某个时间段内的时间序列数据，可按时间排序,返回的tspair结构为：[{T,V},{T,V}]. Batch query time-series data of multiple device indicators by time and order by time,return data structure:[{T,V},{T,V}]  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_iot_timeseries_batch_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TimeseriesInput] timeseries_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TimeseriesBatchOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v2_iot_timeseries_batch_post_with_http_info(**kwargs)  # noqa: E501

    def api_v2_iot_timeseries_batch_post_with_http_info(self, **kwargs):  # noqa: E501
        """批量查询多个设备指标的时间序列数据，按时间排序 Batch query time-series data of device indicators order by time  # noqa: E501

        批量查询多个设备指标在某个时间段内的时间序列数据，可按时间排序,返回的tspair结构为：[{T,V},{T,V}]. Batch query time-series data of multiple device indicators by time and order by time,return data structure:[{T,V},{T,V}]  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v2_iot_timeseries_batch_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TimeseriesInput] timeseries_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TimeseriesBatchOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'timeseries_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v2_iot_timeseries_batch_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'timeseries_input' in local_var_params:
            body_params = local_var_params['timeseries_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v2/iot/timeseries-batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TimeseriesBatchOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v3_iot_save_telemetry_data_batch_post(self, **kwargs):  # noqa: E501
        """以结构化的数据格式批量保存或更新实测数据 / Save or update measured data in batches in a structured data format  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v3_iot_save_telemetry_data_batch_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SaveTelemetryStructDataBatchInput] save_telemetry_struct_data_batch_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v3_iot_save_telemetry_data_batch_post_with_http_info(**kwargs)  # noqa: E501

    def api_v3_iot_save_telemetry_data_batch_post_with_http_info(self, **kwargs):  # noqa: E501
        """以结构化的数据格式批量保存或更新实测数据 / Save or update measured data in batches in a structured data format  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v3_iot_save_telemetry_data_batch_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[SaveTelemetryStructDataBatchInput] save_telemetry_struct_data_batch_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'save_telemetry_struct_data_batch_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v3_iot_save_telemetry_data_batch_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'save_telemetry_struct_data_batch_input' in local_var_params:
            body_params = local_var_params['save_telemetry_struct_data_batch_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3/iot/save-telemetry-data-batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_v3_iot_timeseries_batch_post(self, **kwargs):  # noqa: E501
        """根据指标获取实测时序数据,返回的tspair结构为：T[],V[]. Batch query time-series data of multiple device indicators by time and order by time,return data structure:T[],V[]  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v3_iot_timeseries_batch_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TimeseriesBatchForV3Input] timeseries_batch_for_v3_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[TimeseriesBatchForV3Output]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_v3_iot_timeseries_batch_post_with_http_info(**kwargs)  # noqa: E501

    def api_v3_iot_timeseries_batch_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据指标获取实测时序数据,返回的tspair结构为：T[],V[]. Batch query time-series data of multiple device indicators by time and order by time,return data structure:T[],V[]  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_v3_iot_timeseries_batch_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[TimeseriesBatchForV3Input] timeseries_batch_for_v3_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[TimeseriesBatchForV3Output], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'timeseries_batch_for_v3_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_v3_iot_timeseries_batch_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'timeseries_batch_for_v3_input' in local_var_params:
            body_params = local_var_params['timeseries_batch_for_v3_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3/iot/timeseries-batch', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[TimeseriesBatchForV3Output]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class AddControlDeviceInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'device_code': 'str',
        'indicator': 'str',
        'measure_value': 'float',
        'recommend_value': 'float',
        'recommend': 'str',
        'is_intelligent_control': 'bool',
        'sort': 'int'
    }

    attribute_map = {
        'device_code': 'deviceCode',
        'indicator': 'indicator',
        'measure_value': 'measureValue',
        'recommend_value': 'recommendValue',
        'recommend': 'recommend',
        'is_intelligent_control': 'isIntelligentControl',
        'sort': 'sort'
    }

    def __init__(self, device_code=None, indicator=None, measure_value=None, recommend_value=None, recommend=None, is_intelligent_control=None, sort=None, local_vars_configuration=None):  # noqa: E501
        """AddControlDeviceInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._device_code = None
        self._indicator = None
        self._measure_value = None
        self._recommend_value = None
        self._recommend = None
        self._is_intelligent_control = None
        self._sort = None
        self.discriminator = None

        self.device_code = device_code
        self.indicator = indicator
        if measure_value is not None:
            self.measure_value = measure_value
        if recommend_value is not None:
            self.recommend_value = recommend_value
        self.recommend = recommend
        if is_intelligent_control is not None:
            self.is_intelligent_control = is_intelligent_control
        if sort is not None:
            self.sort = sort

    @property
    def device_code(self):
        """Gets the device_code of this AddControlDeviceInput.  # noqa: E501


        :return: The device_code of this AddControlDeviceInput.  # noqa: E501
        :rtype: str
        """
        return self._device_code

    @device_code.setter
    def device_code(self, device_code):
        """Sets the device_code of this AddControlDeviceInput.


        :param device_code: The device_code of this AddControlDeviceInput.  # noqa: E501
        :type: str
        """

        self._device_code = device_code

    @property
    def indicator(self):
        """Gets the indicator of this AddControlDeviceInput.  # noqa: E501


        :return: The indicator of this AddControlDeviceInput.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this AddControlDeviceInput.


        :param indicator: The indicator of this AddControlDeviceInput.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def measure_value(self):
        """Gets the measure_value of this AddControlDeviceInput.  # noqa: E501


        :return: The measure_value of this AddControlDeviceInput.  # noqa: E501
        :rtype: float
        """
        return self._measure_value

    @measure_value.setter
    def measure_value(self, measure_value):
        """Sets the measure_value of this AddControlDeviceInput.


        :param measure_value: The measure_value of this AddControlDeviceInput.  # noqa: E501
        :type: float
        """

        self._measure_value = measure_value

    @property
    def recommend_value(self):
        """Gets the recommend_value of this AddControlDeviceInput.  # noqa: E501


        :return: The recommend_value of this AddControlDeviceInput.  # noqa: E501
        :rtype: float
        """
        return self._recommend_value

    @recommend_value.setter
    def recommend_value(self, recommend_value):
        """Sets the recommend_value of this AddControlDeviceInput.


        :param recommend_value: The recommend_value of this AddControlDeviceInput.  # noqa: E501
        :type: float
        """

        self._recommend_value = recommend_value

    @property
    def recommend(self):
        """Gets the recommend of this AddControlDeviceInput.  # noqa: E501


        :return: The recommend of this AddControlDeviceInput.  # noqa: E501
        :rtype: str
        """
        return self._recommend

    @recommend.setter
    def recommend(self, recommend):
        """Sets the recommend of this AddControlDeviceInput.


        :param recommend: The recommend of this AddControlDeviceInput.  # noqa: E501
        :type: str
        """

        self._recommend = recommend

    @property
    def is_intelligent_control(self):
        """Gets the is_intelligent_control of this AddControlDeviceInput.  # noqa: E501


        :return: The is_intelligent_control of this AddControlDeviceInput.  # noqa: E501
        :rtype: bool
        """
        return self._is_intelligent_control

    @is_intelligent_control.setter
    def is_intelligent_control(self, is_intelligent_control):
        """Sets the is_intelligent_control of this AddControlDeviceInput.


        :param is_intelligent_control: The is_intelligent_control of this AddControlDeviceInput.  # noqa: E501
        :type: bool
        """

        self._is_intelligent_control = is_intelligent_control

    @property
    def sort(self):
        """Gets the sort of this AddControlDeviceInput.  # noqa: E501


        :return: The sort of this AddControlDeviceInput.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this AddControlDeviceInput.


        :param sort: The sort of this AddControlDeviceInput.  # noqa: E501
        :type: int
        """

        self._sort = sort

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AddControlDeviceInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AddControlDeviceInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class LatestWarningOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'warning_type': 'str',
        'content': 'str',
        'value': 'float',
        'is_warning': 'bool'
    }

    attribute_map = {
        'warning_type': 'warningType',
        'content': 'content',
        'value': 'value',
        'is_warning': 'isWarning'
    }

    def __init__(self, warning_type=None, content=None, value=None, is_warning=None, local_vars_configuration=None):  # noqa: E501
        """LatestWarningOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._warning_type = None
        self._content = None
        self._value = None
        self._is_warning = None
        self.discriminator = None

        self.warning_type = warning_type
        self.content = content
        if value is not None:
            self.value = value
        if is_warning is not None:
            self.is_warning = is_warning

    @property
    def warning_type(self):
        """Gets the warning_type of this LatestWarningOutput.  # noqa: E501

        预警类型  # noqa: E501

        :return: The warning_type of this LatestWarningOutput.  # noqa: E501
        :rtype: str
        """
        return self._warning_type

    @warning_type.setter
    def warning_type(self, warning_type):
        """Sets the warning_type of this LatestWarningOutput.

        预警类型  # noqa: E501

        :param warning_type: The warning_type of this LatestWarningOutput.  # noqa: E501
        :type: str
        """

        self._warning_type = warning_type

    @property
    def content(self):
        """Gets the content of this LatestWarningOutput.  # noqa: E501

        预警内容  # noqa: E501

        :return: The content of this LatestWarningOutput.  # noqa: E501
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """Sets the content of this LatestWarningOutput.

        预警内容  # noqa: E501

        :param content: The content of this LatestWarningOutput.  # noqa: E501
        :type: str
        """

        self._content = content

    @property
    def value(self):
        """Gets the value of this LatestWarningOutput.  # noqa: E501

        报警值  # noqa: E501

        :return: The value of this LatestWarningOutput.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this LatestWarningOutput.

        报警值  # noqa: E501

        :param value: The value of this LatestWarningOutput.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def is_warning(self):
        """Gets the is_warning of this LatestWarningOutput.  # noqa: E501

        是否正在预警  # noqa: E501

        :return: The is_warning of this LatestWarningOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_warning

    @is_warning.setter
    def is_warning(self, is_warning):
        """Sets the is_warning of this LatestWarningOutput.

        是否正在预警  # noqa: E501

        :param is_warning: The is_warning of this LatestWarningOutput.  # noqa: E501
        :type: bool
        """

        self._is_warning = is_warning

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LatestWarningOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LatestWarningOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class Point(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'factory': 'GeometryFactory',
        'user_data': 'Null',
        'srid': 'int',
        'precision_model': 'PrecisionModel',
        'num_geometries': 'int',
        'is_simple': 'bool',
        'is_valid': 'bool',
        'area': 'float',
        'length': 'float',
        'centroid': 'Point',
        'interior_point': 'Point',
        'point_on_surface': 'Point',
        'envelope': 'Geometry',
        'envelope_internal': 'Envelope',
        'is_rectangle': 'bool',
        'coordinate_sequence': 'CoordinateSequence',
        'coordinates': 'list[Coordinate]',
        'num_points': 'int',
        'is_empty': 'bool',
        'dimension': 'int',
        'boundary_dimension': 'int',
        'x': 'float',
        'y': 'float',
        'coordinate': 'Coordinate',
        'geometry_type': 'str',
        'ogc_geometry_type': 'int',
        'boundary': 'Geometry',
        'z': 'float',
        'm': 'float'
    }

    attribute_map = {
        'factory': 'factory',
        'user_data': 'userData',
        'srid': 'srid',
        'precision_model': 'precisionModel',
        'num_geometries': 'numGeometries',
        'is_simple': 'isSimple',
        'is_valid': 'isValid',
        'area': 'area',
        'length': 'length',
        'centroid': 'centroid',
        'interior_point': 'interiorPoint',
        'point_on_surface': 'pointOnSurface',
        'envelope': 'envelope',
        'envelope_internal': 'envelopeInternal',
        'is_rectangle': 'isRectangle',
        'coordinate_sequence': 'coordinateSequence',
        'coordinates': 'coordinates',
        'num_points': 'numPoints',
        'is_empty': 'isEmpty',
        'dimension': 'dimension',
        'boundary_dimension': 'boundaryDimension',
        'x': 'x',
        'y': 'y',
        'coordinate': 'coordinate',
        'geometry_type': 'geometryType',
        'ogc_geometry_type': 'ogcGeometryType',
        'boundary': 'boundary',
        'z': 'z',
        'm': 'm'
    }

    def __init__(self, factory=None, user_data=None, srid=None, precision_model=None, num_geometries=None, is_simple=None, is_valid=None, area=None, length=None, centroid=None, interior_point=None, point_on_surface=None, envelope=None, envelope_internal=None, is_rectangle=None, coordinate_sequence=None, coordinates=None, num_points=None, is_empty=None, dimension=None, boundary_dimension=None, x=None, y=None, coordinate=None, geometry_type=None, ogc_geometry_type=None, boundary=None, z=None, m=None, local_vars_configuration=None):  # noqa: E501
        """Point - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._factory = None
        self._user_data = None
        self._srid = None
        self._precision_model = None
        self._num_geometries = None
        self._is_simple = None
        self._is_valid = None
        self._area = None
        self._length = None
        self._centroid = None
        self._interior_point = None
        self._point_on_surface = None
        self._envelope = None
        self._envelope_internal = None
        self._is_rectangle = None
        self._coordinate_sequence = None
        self._coordinates = None
        self._num_points = None
        self._is_empty = None
        self._dimension = None
        self._boundary_dimension = None
        self._x = None
        self._y = None
        self._coordinate = None
        self._geometry_type = None
        self._ogc_geometry_type = None
        self._boundary = None
        self._z = None
        self._m = None
        self.discriminator = None

        if factory is not None:
            self.factory = factory
        if user_data is not None:
            self.user_data = user_data
        if srid is not None:
            self.srid = srid
        if precision_model is not None:
            self.precision_model = precision_model
        if num_geometries is not None:
            self.num_geometries = num_geometries
        if is_simple is not None:
            self.is_simple = is_simple
        if is_valid is not None:
            self.is_valid = is_valid
        if area is not None:
            self.area = area
        if length is not None:
            self.length = length
        if centroid is not None:
            self.centroid = centroid
        if interior_point is not None:
            self.interior_point = interior_point
        if point_on_surface is not None:
            self.point_on_surface = point_on_surface
        if envelope is not None:
            self.envelope = envelope
        if envelope_internal is not None:
            self.envelope_internal = envelope_internal
        if is_rectangle is not None:
            self.is_rectangle = is_rectangle
        if coordinate_sequence is not None:
            self.coordinate_sequence = coordinate_sequence
        self.coordinates = coordinates
        if num_points is not None:
            self.num_points = num_points
        if is_empty is not None:
            self.is_empty = is_empty
        if dimension is not None:
            self.dimension = dimension
        if boundary_dimension is not None:
            self.boundary_dimension = boundary_dimension
        if x is not None:
            self.x = x
        if y is not None:
            self.y = y
        if coordinate is not None:
            self.coordinate = coordinate
        self.geometry_type = geometry_type
        if ogc_geometry_type is not None:
            self.ogc_geometry_type = ogc_geometry_type
        if boundary is not None:
            self.boundary = boundary
        if z is not None:
            self.z = z
        if m is not None:
            self.m = m

    @property
    def factory(self):
        """Gets the factory of this Point.  # noqa: E501


        :return: The factory of this Point.  # noqa: E501
        :rtype: GeometryFactory
        """
        return self._factory

    @factory.setter
    def factory(self, factory):
        """Sets the factory of this Point.


        :param factory: The factory of this Point.  # noqa: E501
        :type: GeometryFactory
        """

        self._factory = factory

    @property
    def user_data(self):
        """Gets the user_data of this Point.  # noqa: E501


        :return: The user_data of this Point.  # noqa: E501
        :rtype: Null
        """
        return self._user_data

    @user_data.setter
    def user_data(self, user_data):
        """Sets the user_data of this Point.


        :param user_data: The user_data of this Point.  # noqa: E501
        :type: Null
        """

        self._user_data = user_data

    @property
    def srid(self):
        """Gets the srid of this Point.  # noqa: E501


        :return: The srid of this Point.  # noqa: E501
        :rtype: int
        """
        return self._srid

    @srid.setter
    def srid(self, srid):
        """Sets the srid of this Point.


        :param srid: The srid of this Point.  # noqa: E501
        :type: int
        """

        self._srid = srid

    @property
    def precision_model(self):
        """Gets the precision_model of this Point.  # noqa: E501


        :return: The precision_model of this Point.  # noqa: E501
        :rtype: PrecisionModel
        """
        return self._precision_model

    @precision_model.setter
    def precision_model(self, precision_model):
        """Sets the precision_model of this Point.


        :param precision_model: The precision_model of this Point.  # noqa: E501
        :type: PrecisionModel
        """

        self._precision_model = precision_model

    @property
    def num_geometries(self):
        """Gets the num_geometries of this Point.  # noqa: E501


        :return: The num_geometries of this Point.  # noqa: E501
        :rtype: int
        """
        return self._num_geometries

    @num_geometries.setter
    def num_geometries(self, num_geometries):
        """Sets the num_geometries of this Point.


        :param num_geometries: The num_geometries of this Point.  # noqa: E501
        :type: int
        """

        self._num_geometries = num_geometries

    @property
    def is_simple(self):
        """Gets the is_simple of this Point.  # noqa: E501


        :return: The is_simple of this Point.  # noqa: E501
        :rtype: bool
        """
        return self._is_simple

    @is_simple.setter
    def is_simple(self, is_simple):
        """Sets the is_simple of this Point.


        :param is_simple: The is_simple of this Point.  # noqa: E501
        :type: bool
        """

        self._is_simple = is_simple

    @property
    def is_valid(self):
        """Gets the is_valid of this Point.  # noqa: E501


        :return: The is_valid of this Point.  # noqa: E501
        :rtype: bool
        """
        return self._is_valid

    @is_valid.setter
    def is_valid(self, is_valid):
        """Sets the is_valid of this Point.


        :param is_valid: The is_valid of this Point.  # noqa: E501
        :type: bool
        """

        self._is_valid = is_valid

    @property
    def area(self):
        """Gets the area of this Point.  # noqa: E501


        :return: The area of this Point.  # noqa: E501
        :rtype: float
        """
        return self._area

    @area.setter
    def area(self, area):
        """Sets the area of this Point.


        :param area: The area of this Point.  # noqa: E501
        :type: float
        """

        self._area = area

    @property
    def length(self):
        """Gets the length of this Point.  # noqa: E501


        :return: The length of this Point.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this Point.


        :param length: The length of this Point.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def centroid(self):
        """Gets the centroid of this Point.  # noqa: E501


        :return: The centroid of this Point.  # noqa: E501
        :rtype: Point
        """
        return self._centroid

    @centroid.setter
    def centroid(self, centroid):
        """Sets the centroid of this Point.


        :param centroid: The centroid of this Point.  # noqa: E501
        :type: Point
        """

        self._centroid = centroid

    @property
    def interior_point(self):
        """Gets the interior_point of this Point.  # noqa: E501


        :return: The interior_point of this Point.  # noqa: E501
        :rtype: Point
        """
        return self._interior_point

    @interior_point.setter
    def interior_point(self, interior_point):
        """Sets the interior_point of this Point.


        :param interior_point: The interior_point of this Point.  # noqa: E501
        :type: Point
        """

        self._interior_point = interior_point

    @property
    def point_on_surface(self):
        """Gets the point_on_surface of this Point.  # noqa: E501


        :return: The point_on_surface of this Point.  # noqa: E501
        :rtype: Point
        """
        return self._point_on_surface

    @point_on_surface.setter
    def point_on_surface(self, point_on_surface):
        """Sets the point_on_surface of this Point.


        :param point_on_surface: The point_on_surface of this Point.  # noqa: E501
        :type: Point
        """

        self._point_on_surface = point_on_surface

    @property
    def envelope(self):
        """Gets the envelope of this Point.  # noqa: E501


        :return: The envelope of this Point.  # noqa: E501
        :rtype: Geometry
        """
        return self._envelope

    @envelope.setter
    def envelope(self, envelope):
        """Sets the envelope of this Point.


        :param envelope: The envelope of this Point.  # noqa: E501
        :type: Geometry
        """

        self._envelope = envelope

    @property
    def envelope_internal(self):
        """Gets the envelope_internal of this Point.  # noqa: E501


        :return: The envelope_internal of this Point.  # noqa: E501
        :rtype: Envelope
        """
        return self._envelope_internal

    @envelope_internal.setter
    def envelope_internal(self, envelope_internal):
        """Sets the envelope_internal of this Point.


        :param envelope_internal: The envelope_internal of this Point.  # noqa: E501
        :type: Envelope
        """

        self._envelope_internal = envelope_internal

    @property
    def is_rectangle(self):
        """Gets the is_rectangle of this Point.  # noqa: E501


        :return: The is_rectangle of this Point.  # noqa: E501
        :rtype: bool
        """
        return self._is_rectangle

    @is_rectangle.setter
    def is_rectangle(self, is_rectangle):
        """Sets the is_rectangle of this Point.


        :param is_rectangle: The is_rectangle of this Point.  # noqa: E501
        :type: bool
        """

        self._is_rectangle = is_rectangle

    @property
    def coordinate_sequence(self):
        """Gets the coordinate_sequence of this Point.  # noqa: E501


        :return: The coordinate_sequence of this Point.  # noqa: E501
        :rtype: CoordinateSequence
        """
        return self._coordinate_sequence

    @coordinate_sequence.setter
    def coordinate_sequence(self, coordinate_sequence):
        """Sets the coordinate_sequence of this Point.


        :param coordinate_sequence: The coordinate_sequence of this Point.  # noqa: E501
        :type: CoordinateSequence
        """

        self._coordinate_sequence = coordinate_sequence

    @property
    def coordinates(self):
        """Gets the coordinates of this Point.  # noqa: E501


        :return: The coordinates of this Point.  # noqa: E501
        :rtype: list[Coordinate]
        """
        return self._coordinates

    @coordinates.setter
    def coordinates(self, coordinates):
        """Sets the coordinates of this Point.


        :param coordinates: The coordinates of this Point.  # noqa: E501
        :type: list[Coordinate]
        """

        self._coordinates = coordinates

    @property
    def num_points(self):
        """Gets the num_points of this Point.  # noqa: E501


        :return: The num_points of this Point.  # noqa: E501
        :rtype: int
        """
        return self._num_points

    @num_points.setter
    def num_points(self, num_points):
        """Sets the num_points of this Point.


        :param num_points: The num_points of this Point.  # noqa: E501
        :type: int
        """

        self._num_points = num_points

    @property
    def is_empty(self):
        """Gets the is_empty of this Point.  # noqa: E501


        :return: The is_empty of this Point.  # noqa: E501
        :rtype: bool
        """
        return self._is_empty

    @is_empty.setter
    def is_empty(self, is_empty):
        """Sets the is_empty of this Point.


        :param is_empty: The is_empty of this Point.  # noqa: E501
        :type: bool
        """

        self._is_empty = is_empty

    @property
    def dimension(self):
        """Gets the dimension of this Point.  # noqa: E501

        0-P 0-Point 1-Curve 1-L 2-A 2-Surface 3-Collapse -3-Dontcare -2-True -1-Unknown -1-False   # noqa: E501

        :return: The dimension of this Point.  # noqa: E501
        :rtype: int
        """
        return self._dimension

    @dimension.setter
    def dimension(self, dimension):
        """Sets the dimension of this Point.

        0-P 0-Point 1-Curve 1-L 2-A 2-Surface 3-Collapse -3-Dontcare -2-True -1-Unknown -1-False   # noqa: E501

        :param dimension: The dimension of this Point.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, -3, -2, -1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and dimension not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `dimension` ({0}), must be one of {1}"  # noqa: E501
                .format(dimension, allowed_values)
            )

        self._dimension = dimension

    @property
    def boundary_dimension(self):
        """Gets the boundary_dimension of this Point.  # noqa: E501

        0-P 0-Point 1-Curve 1-L 2-A 2-Surface 3-Collapse -3-Dontcare -2-True -1-Unknown -1-False   # noqa: E501

        :return: The boundary_dimension of this Point.  # noqa: E501
        :rtype: int
        """
        return self._boundary_dimension

    @boundary_dimension.setter
    def boundary_dimension(self, boundary_dimension):
        """Sets the boundary_dimension of this Point.

        0-P 0-Point 1-Curve 1-L 2-A 2-Surface 3-Collapse -3-Dontcare -2-True -1-Unknown -1-False   # noqa: E501

        :param boundary_dimension: The boundary_dimension of this Point.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2, 3, -3, -2, -1]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and boundary_dimension not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `boundary_dimension` ({0}), must be one of {1}"  # noqa: E501
                .format(boundary_dimension, allowed_values)
            )

        self._boundary_dimension = boundary_dimension

    @property
    def x(self):
        """Gets the x of this Point.  # noqa: E501


        :return: The x of this Point.  # noqa: E501
        :rtype: float
        """
        return self._x

    @x.setter
    def x(self, x):
        """Sets the x of this Point.


        :param x: The x of this Point.  # noqa: E501
        :type: float
        """

        self._x = x

    @property
    def y(self):
        """Gets the y of this Point.  # noqa: E501


        :return: The y of this Point.  # noqa: E501
        :rtype: float
        """
        return self._y

    @y.setter
    def y(self, y):
        """Sets the y of this Point.


        :param y: The y of this Point.  # noqa: E501
        :type: float
        """

        self._y = y

    @property
    def coordinate(self):
        """Gets the coordinate of this Point.  # noqa: E501


        :return: The coordinate of this Point.  # noqa: E501
        :rtype: Coordinate
        """
        return self._coordinate

    @coordinate.setter
    def coordinate(self, coordinate):
        """Sets the coordinate of this Point.


        :param coordinate: The coordinate of this Point.  # noqa: E501
        :type: Coordinate
        """

        self._coordinate = coordinate

    @property
    def geometry_type(self):
        """Gets the geometry_type of this Point.  # noqa: E501


        :return: The geometry_type of this Point.  # noqa: E501
        :rtype: str
        """
        return self._geometry_type

    @geometry_type.setter
    def geometry_type(self, geometry_type):
        """Sets the geometry_type of this Point.


        :param geometry_type: The geometry_type of this Point.  # noqa: E501
        :type: str
        """

        self._geometry_type = geometry_type

    @property
    def ogc_geometry_type(self):
        """Gets the ogc_geometry_type of this Point.  # noqa: E501

        1-Point 2-LineString 3-Polygon 4-MultiPoint 5-MultiLineString 6-MultiPolygon 7-GeometryCollection 8-CircularString 9-CompoundCurve 10-CurvePolygon 11-MultiCurve 12-MultiSurface 13-Curve 14-Surface 15-PolyhedralSurface 16-TIN   # noqa: E501

        :return: The ogc_geometry_type of this Point.  # noqa: E501
        :rtype: int
        """
        return self._ogc_geometry_type

    @ogc_geometry_type.setter
    def ogc_geometry_type(self, ogc_geometry_type):
        """Sets the ogc_geometry_type of this Point.

        1-Point 2-LineString 3-Polygon 4-MultiPoint 5-MultiLineString 6-MultiPolygon 7-GeometryCollection 8-CircularString 9-CompoundCurve 10-CurvePolygon 11-MultiCurve 12-MultiSurface 13-Curve 14-Surface 15-PolyhedralSurface 16-TIN   # noqa: E501

        :param ogc_geometry_type: The ogc_geometry_type of this Point.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and ogc_geometry_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `ogc_geometry_type` ({0}), must be one of {1}"  # noqa: E501
                .format(ogc_geometry_type, allowed_values)
            )

        self._ogc_geometry_type = ogc_geometry_type

    @property
    def boundary(self):
        """Gets the boundary of this Point.  # noqa: E501


        :return: The boundary of this Point.  # noqa: E501
        :rtype: Geometry
        """
        return self._boundary

    @boundary.setter
    def boundary(self, boundary):
        """Sets the boundary of this Point.


        :param boundary: The boundary of this Point.  # noqa: E501
        :type: Geometry
        """

        self._boundary = boundary

    @property
    def z(self):
        """Gets the z of this Point.  # noqa: E501


        :return: The z of this Point.  # noqa: E501
        :rtype: float
        """
        return self._z

    @z.setter
    def z(self, z):
        """Sets the z of this Point.


        :param z: The z of this Point.  # noqa: E501
        :type: float
        """

        self._z = z

    @property
    def m(self):
        """Gets the m of this Point.  # noqa: E501


        :return: The m of this Point.  # noqa: E501
        :rtype: float
        """
        return self._m

    @m.setter
    def m(self, m):
        """Sets the m of this Point.


        :param m: The m of this Point.  # noqa: E501
        :type: float
        """

        self._m = m

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Point):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Point):
            return True

        return self.to_dict() != other.to_dict()
